set more 1

/*
File:	cepr_jt_jt.do
Date:	Aug 31, 2004
Desc:	Create consistent extract of Job Tenure and Mobility Supplement for 
	1998, 2000, 2002, and 2004 
Note:	See copyright notice at end of program.
*/

/* Determine data year */

local year=year in 1
lab var year "Year"

/* Tenure with current employer */

gen ten_num=.

if 1998<=`year' & `year'<=2004 {
replace ten_num=pest1a
replace ten_num=. if pest1a<0
}
lab var ten_num "Tenure, number"
notes ten_num: "How long have you been working CONTINUOUSLY for /*
*/ company name / as a self-employed person / at your main job /*
*/ for your present employer?"
notes ten_num: Number only; for units see ten_per
notes ten_num: CPS: pest1a

gen ten_per=.

if 1998<=`year' & `year'<=2004 {
replace ten_per=pest1b
replace ten_per=. if pest1b<0
}
lab var ten_per "Tenure, period"
lab def ten_per 1 Days 2 Weeks 3 Months 4 Years
lab val ten_per ten_per
notes ten_per: "How long have you been working CONTINUOUSLY for /*
*/ company name / as a self-employed person / at your main job /*
*/ for your present employer?"
notes ten_per: Period only; for units see ten_num
notes ten_per: CPS: pest1b

	/* check for short-tenure workers */

gen ten_mth=.

if 1998<=`year' & `year'<=2004 {
replace ten_mth=pest3
replace ten_mth=. if pest3<0
}
lab var ten_mth "Short tenure, months"
notes ten_mth: Asked as check, only if reported tenure in pest1a, /*
*/ pest1b was less than 3 years
notes ten_mth: CPS: pest3

	/* continuous tenure, raw */

gen ten_raw=.

if 1998<=`year' & `year'<=2004 {
replace ten_raw=ten_num/365 if ten_per==1
replace ten_raw=ten_num/52 if ten_per==2
replace ten_raw=ten_num/12 if ten_per==3
replace ten_raw=ten_num if ten_per==4
replace ten_raw=ten_mth/12 if ten_mth~=. /* use checked data if available */
}
lab var ten_raw "Tenure, years, no BLS recode"
notes ten_raw: Tenure calculated directly from CPS pest1a, pest1b, pest3

/* Tenure with current employer: BLS recode */

gen tenure=.

if 1998<=`year' & `year'<=2004 {
replace tenure=prst1tn
}
lab var tenure "Tenure, years, BLS"
notes tenure: Recode for employer tenure; recode incorporates usable /*
*/ responses from PEST1A, PEST1B, and (when appropriate) PEST3. A usable /*
*/ response had to be within the range 1-99 for PEST1A (and 1-35 for /*
*/ PEST3), and had to have age minus tenure equal to 14+ years.
notes tenure: CPS: prst1tn

/* Previous spells of employment with current employer */

gen prevten=.

if `year'==1998 {
replace prevten=1 if pest4==1
replace prevten=0 if pest4==2
}
lab var prevten "Previous spell w/ employer"
notes prevten: "Did you have any previous periods of employment with /*
*/ company name / your main employer / your present employer in addition /*
*/ to the period you just told me?"
notes prevten: CPS: pest4

gen tot_num=.

if `year'==1998 {
replace tot_num=pest5a
replace tot_num=. if pest5a<0
}
lab var tot_num "Total tenure, number"
notes tot_num: "Altogether, how long have you worked at /*
*/ company name / at your main job / for your present employer?"
notes tot_num: Number only; for units see tot_per
notes tot_num: PEST5A, PEST5B, and PEST4 were not intended to /*
*/ be used to calculate tenure with present employer. They were asked /*
*/ solely to help researchers assess whether respondents provide /*
*/ information on CONTINUOUS tenure or TOTAL tenure, and whether the /*
*/ distinction is even meaningful."
notes tot_num: Only available 1998.
notes tot_num: CPS: pest5a

gen tot_per=.

if `year'==1998 {
replace tot_per=pest5b
replace tot_per=. if pest5b<0
}
lab var tot_per "Total tenure, period"
lab val tot_per ten_per /* use label from ten_per variable */
notes tot_per: "Altogether, how long have you worked at /*
*/ company name / at your main job / for your present employer?"
notes tot_per: Period only; for number see tot_num
notes tot_per: PEST5A, PEST5B, and PEST4 were not intended to /*
*/ be used to calculate tenure with present employer. They were asked /*
*/ solely to help researchers assess whether respondents provide /*
*/ information on CONTINUOUS tenure or TOTAL tenure, and whether the /*
*/ distinction is even meaningful."
notes tot_per: Only available 1998.
notes tot_per: CPS: pest5b

	/* total tenure */

gen tot_ten=.

if `year'==1998 {
replace tot_ten=tot_num/365 if tot_per==1
replace tot_ten=tot_num/52 if tot_per==2
replace tot_ten=tot_num/12 if tot_per==3
replace tot_ten=tot_num if tot_per==4
}
lab var tot_ten "Total tenure, years"
notes tot_ten: PEST5A, PEST5B, and PEST4 were not intended to /*
*/ be used to calculate tenure with present employer. They were asked /*
*/ solely to help researchers assess whether respondents provide /*
*/ information on CONTINUOUS tenure or TOTAL tenure, and whether the /*
*/ distinction is even meaningful."
notes tot_ten: Only available 1998.
notes tot_ten: Total tenure calculated directly from CPS /*
*/ pest4, pest5a, pest5b

/* Working a year ago */

gen byte yearago=.

if 2000<=`year' & `year'<=2004 {
replace yearago=1 if pest8==1
replace yearago=0 if pest8==2
}
lab var yearago "Working one year ago"
notes yearago: Only available 2000-
notes yearago: CPS: pest8

/* job tenure and occupational mobility supplement weight */

gen jtwgt=.

if 1998<=`year' & `year'<=2004 {
replace jtwgt=pwtenwgt
}
lab var jtwgt "Job Tenure weight"
notes jtwgt: CPS: pwtenwgt

/* job tenure and occupational mobility interview status */

gen jtstat=.

if 1998<=`year' & `year'<=2004 {
replace jtstat=prtensat
}
lab var jtstat "Job Tenure interview status"
lab def jtstat 1 "Not eligible" 2 "Interview" 3 "Noninterview"
lab val jtstat jtstat
notes jtstat: Eligible cases had to meet the following criteria: /*
*/ hrinsta=1, prtage=15+, prpertyp=2, and pemlr=1 or 2
notes jtstat: Interviews had to meet the following criteria: /*
*/ pest1a=1-99 and pest1b=1-4
notes jtstat: Noninterview cases met the eligibility criteria, but /*
*/ did not meet the interview criteria
notes jtstat: CPS: prtensat

/* 
Copyright 2004 CEPR and John Schmitt

This file is part of the cepr_dws_master.do program. This file and all
programs referenced in it are free software. You can redistribute the
program or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA.
*/
